@@ -764,7 +764,7 @@ class GridPlot:
         diag_target_kws["scatter_kws"] = None
         if values is None:
             from _statistics import getMaxLogFunc
-            maxLogFunc = _statistics.getMaxLogFunc(dataFrame=self._dfref())
+            maxLogFunc = getMaxLogFunc(dataFrame=self._dfref())
             values = maxLogFunc.state
         for irow, targetRow in enumerate(self.currentFig.targetList[:]):
 
